@@ -6,6 +6,10 @@ from .. import utils
 
 
 class MojangPlayer:
+    """
+    The response from a call to the Mojang API
+    Represents a player
+    """
     def __init__(self, data):
         self.name = data["name"]
         self.uuid = data["id"]
@@ -18,6 +22,10 @@ class MojangPlayer:
 
 
 class NameHistory:
+    """
+    The response from a call to the Mojang namehistory API
+    Represents a player's namehistory as an iterable
+    """
     def __init__(self, data):
         self.data = data
 
@@ -33,33 +41,53 @@ class NameHistory:
 
 
 class NameHistoryEntry:
+    """
+    Represents a name in the namehistory of a player
+    """
     def __init__(self, data):
         self.name = data["name"]
-        self.time = datetime.date.fromtimestamp(data["changedToAt"] / 1000)
+        self.time = datetime.datetime.fromtimestamp(data["changedToAt"] / 1000)
+
+    def __str__(self):
+        return self.name
 
 
 class HypixelPlayer:
+    """
+    The response from a call to the Hypixel player endpoint
+    Represents a player
+    """
     def __init__(self, data):
         self.name = data.get("player", {}).get("displayname")
         self.uuid = data.get("player", {}).get("uuid")
         self.rank = Rank(data)
+        self.display = utils.get_profile_display(self.name, self.rank)
         self.level = Level(data)
         self.karma = data.get("player", {}).get("karma", 0)
         self.achievement_points = data.get("player", {}).get("achievementPoints", 0)
-        self.logins = LoginTimes(data)
-        self.social_media = SocialMedia(data)
+        self.logins = Logins(data)
+        self.social = Social(data)
         self.bedwars = Bedwars(data)
         self.skywars = Skywars(data)
         self.duels = Duels(data)
 
+    def __str__(self):
+        return self.name
 
-class LoginTimes:
+
+class Logins:
+    """
+    The login times of a player
+    """
     def __init__(self, data):
         self.first = datetime.datetime.fromtimestamp(data.get("player", {}).get("firstLogin", 0) / 1000)
         self.last = datetime.datetime.fromtimestamp(data.get("player", {}).get("lastLogin", 0) / 1000)
 
 
-class SocialMedia:
+class Social:
+    """
+    The social media links of a player
+    """
     def __init__(self, data):
         self.twitter = data.get("player", {}).get("socialMedia", {}).get("links", {}).get("TWITTER")
         self.youtube = data.get("player", {}).get("socialMedia", {}).get("links", {}).get("YOUTUBE")
@@ -70,6 +98,9 @@ class SocialMedia:
 
 
 class Rank:
+    """
+    The rank data of a player
+    """
     def __init__(self, data):
         self.name = utils.get_rank(
             data.get("player", {}).get("rank"),
